==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/portal/kotlin/inputs/DashboardLensArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.portal.kotlin.inputs

import com.pulumi.azurenative.portal.inputs.DashboardLensArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.Int
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * A dashboard lens.
 * @property metadata The dashboard len's metadata.
 * @property order The lens order.
 * @property parts The dashboard parts.
 */
public data class DashboardLensArgs(
    public val metadata: Output<Map<String, Any>>? = null,
    public val order: Output<Int>,
    public val parts: Output<List<DashboardPartsArgs>>,
) : ConvertibleToJava<com.pulumi.azurenative.portal.inputs.DashboardLensArgs> {
    override fun toJava(): com.pulumi.azurenative.portal.inputs.DashboardLensArgs =
        com.pulumi.azurenative.portal.inputs.DashboardLensArgs.builder()
            .metadata(
                metadata?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .order(order.applyValue({ args0 -> args0 }))
            .parts(
                parts.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [DashboardLensArgs].
 */
@PulumiTagMarker
public class DashboardLensArgsBuilder internal constructor() {
    private var metadata: Output<Map<String, Any>>? = null

    private var order: Output<Int>? = null

    private var parts: Output<List<DashboardPartsArgs>>? = null

    /**
     * @param value The dashboard len's metadata.
     */
    @JvmName("ormjnwhrmqsvjqmp")
    public suspend fun metadata(`value`: Output<Map<String, Any>>) {
        this.metadata = value
    }

    /**
     * @param value The lens order.
     */
    @JvmName("icbydebjguftaxcq")
    public suspend fun order(`value`: Output<Int>) {
        this.order = value
    }

    /**
     * @param value The dashboard parts.
     */
    @JvmName("egcbneyvtvfrcara")
    public suspend fun parts(`value`: Output<List<DashboardPartsArgs>>) {
        this.parts = value
    }

    @JvmName("nnujvctvtohbomam")
    public suspend fun parts(vararg values: Output<DashboardPartsArgs>) {
        this.parts = Output.all(values.asList())
    }

    /**
     * @param values The dashboard parts.
     */
    @JvmName("bmustgkeovypennj")
    public suspend fun parts(values: List<Output<DashboardPartsArgs>>) {
        this.parts = Output.all(values)
    }

    /**
     * @param value The dashboard len's metadata.
     */
    @JvmName("fdjgogyonvxmobgb")
    public suspend fun metadata(`value`: Map<String, Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.metadata = mapped
    }

    /**
     * @param values The dashboard len's metadata.
     */
    @JvmName("nlwimcsacgwanrvq")
    public fun metadata(vararg values: Pair<String, Any>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metadata = mapped
    }

    /**
     * @param value The lens order.
     */
    @JvmName("xwtcpxphtrcenxac")
    public suspend fun order(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.order = mapped
    }

    /**
     * @param value The dashboard parts.
     */
    @JvmName("mysurdvrlceiglik")
    public suspend fun parts(`value`: List<DashboardPartsArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parts = mapped
    }

    /**
     * @param argument The dashboard parts.
     */
    @JvmName("wjyritnyhdlswdag")
    public suspend fun parts(argument: List<suspend DashboardPartsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DashboardPartsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.parts = mapped
    }

    /**
     * @param argument The dashboard parts.
     */
    @JvmName("hvujvuindknkkjfu")
    public suspend fun parts(vararg argument: suspend DashboardPartsArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            DashboardPartsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.parts = mapped
    }

    /**
     * @param argument The dashboard parts.
     */
    @JvmName("lapfddtjulbqywct")
    public suspend fun parts(argument: suspend DashboardPartsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DashboardPartsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.parts = mapped
    }

    /**
     * @param values The dashboard parts.
     */
    @JvmName("kmxlwacbvffobyhh")
    public suspend fun parts(vararg values: DashboardPartsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parts = mapped
    }

    internal fun build(): DashboardLensArgs = DashboardLensArgs(
        metadata = metadata,
        order = order ?: throw PulumiNullFieldException("order"),
        parts = parts ?: throw PulumiNullFieldException("parts"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/portal/kotlin/inputs/DashboardLensArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.portal.kotlin.inputs

import com.pulumi.azurenative.portal.inputs.DashboardLensArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.Int
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * A dashboard lens.
 * @property metadata The dashboard len's metadata.
 * @property order The lens order.
 * @property parts The dashboard parts.
 */
public data class DashboardLensArgs(
    public val metadata: Output<Map<String, Any>>? = null,
    public val order: Output<Int>,
    public val parts: Output<List<DashboardPartsArgs>>,
) : ConvertibleToJava<com.pulumi.azurenative.portal.inputs.DashboardLensArgs> {
    override fun toJava(): com.pulumi.azurenative.portal.inputs.DashboardLensArgs =
        com.pulumi.azurenative.portal.inputs.DashboardLensArgs.builder()
            .metadata(
                metadata?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .order(order.applyValue({ args0 -> args0 }))
            .parts(
                parts.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [DashboardLensArgs].
 */
@PulumiTagMarker
public class DashboardLensArgsBuilder internal constructor() {
    private var metadata: Output<Map<String, Any>>? = null

    private var order: Output<Int>? = null

    private var parts: Output<List<DashboardPartsArgs>>? = null

    /**
     * @param value The dashboard len's metadata.
     */
    @JvmName("msdmmbwbbunqnojy")
    public suspend fun metadata(`value`: Output<Map<String, Any>>) {
        this.metadata = value
    }

    /**
     * @param value The lens order.
     */
    @JvmName("nrfnpsvvpdxwqqlb")
    public suspend fun order(`value`: Output<Int>) {
        this.order = value
    }

    /**
     * @param value The dashboard parts.
     */
    @JvmName("koqthhgocgnqyxsg")
    public suspend fun parts(`value`: Output<List<DashboardPartsArgs>>) {
        this.parts = value
    }

    @JvmName("oaypycdifbxpyyys")
    public suspend fun parts(vararg values: Output<DashboardPartsArgs>) {
        this.parts = Output.all(values.asList())
    }

    /**
     * @param values The dashboard parts.
     */
    @JvmName("sfwkpqgyteijvdse")
    public suspend fun parts(values: List<Output<DashboardPartsArgs>>) {
        this.parts = Output.all(values)
    }

    /**
     * @param value The dashboard len's metadata.
     */
    @JvmName("jvkveaaeyuwpdanx")
    public suspend fun metadata(`value`: Map<String, Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.metadata = mapped
    }

    /**
     * @param values The dashboard len's metadata.
     */
    @JvmName("vatdsermbfggedtn")
    public fun metadata(vararg values: Pair<String, Any>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metadata = mapped
    }

    /**
     * @param value The lens order.
     */
    @JvmName("syruojrjylhqfxur")
    public suspend fun order(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.order = mapped
    }

    /**
     * @param value The dashboard parts.
     */
    @JvmName("jsjxxyjfbkqvnaxb")
    public suspend fun parts(`value`: List<DashboardPartsArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parts = mapped
    }

    /**
     * @param argument The dashboard parts.
     */
    @JvmName("toulostynirnyaub")
    public suspend fun parts(argument: List<suspend DashboardPartsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DashboardPartsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.parts = mapped
    }

    /**
     * @param argument The dashboard parts.
     */
    @JvmName("dcllfbhqqclcyrfe")
    public suspend fun parts(vararg argument: suspend DashboardPartsArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            DashboardPartsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.parts = mapped
    }

    /**
     * @param argument The dashboard parts.
     */
    @JvmName("mhfcjiwugldqicoa")
    public suspend fun parts(argument: suspend DashboardPartsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DashboardPartsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.parts = mapped
    }

    /**
     * @param values The dashboard parts.
     */
    @JvmName("gjcpxlramekmfhbs")
    public suspend fun parts(vararg values: DashboardPartsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parts = mapped
    }

    internal fun build(): DashboardLensArgs = DashboardLensArgs(
        metadata = metadata,
        order = order ?: throw PulumiNullFieldException("order"),
        parts = parts ?: throw PulumiNullFieldException("parts"),
    )
}
